Interface
=========

This page will explain the interface functioning.


.. figure:: interface/array_guides.png
   :alt: Array of guides

   Array of guides settings


.. figure:: interface/curved_guides.png
   :alt: Curved guides

   Curved guides settings (STIRAP)


.. figure:: interface/beams.png
   :alt: Beams settings

   Beams settings


.. figure:: interface/results_array.png
   :alt: Array of guides results
   
   Array of guides results


.. figure:: interface/results_soliton.png
   :alt: Soliton results
   
   Soliton results
